Likelihood
==========

The :py:mod:`.likelihood` module contains functions used to calculate and visualize 
the log-likelihood surfaces for models and data in Curveball.
Functions that use growth data expect a :py:class:`pandas.DataFrame` generated by the :py:mod:`.ioutils` module.
Functions that use often results of model fitting require :py:class:`lmfit.model.ModelResult` objects.

Members
-------

.. automodule:: curveball.likelihood
   :members:
